import React from "react";
import { CircleCheck, Info, TriangleAlert } from "lucide-react";

export type MessageType = "info" | "error" | "warning" | "success";

interface MessageTypeDetails {
  icon: React.ComponentType<{
    className: string;
    size: number;
    strokeWidth: number;
    "aria-hidden": boolean;
  }>;
  colorClass: string;
}

const messageTypeIconMap: Record<MessageType, MessageTypeDetails> = {
  error: {
    icon: CircleCheck,
    colorClass: "text-red-500",
  },
  warning: {
    icon: TriangleAlert,
    colorClass: "text-amber-500",
  },
  success: {
    icon: CircleCheck,
    colorClass: "text-emerald-500",
  },
  info: {
    icon: Info,
    colorClass: "text-blue-500",
  },
};

export interface MessageProps {
  type: MessageType;
  message: string;
}

export function Message({ type, message }: MessageProps) {
  const { icon: Icon, colorClass } = messageTypeIconMap[type];

  return (
    <div className="px-4 py-1 bg-[#3e4452] pb-2">
      <p className="grow text-sm">
        <Icon
          className={`-mt-0.5 me-3 inline-flex ${colorClass}`}
          size={16}
          strokeWidth={2}
          aria-hidden={true}
        />
        {message}
      </p>
    </div>
  );
}
